==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkSphereHandleRepresentation.java <==
// java wrapper for vtkSphereHandleRepresentation object
//

package vtk;
import vtk.*;

public class vtkSphereHandleRepresentation extends vtkHandleRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWorldPosition_2(double id0[]);
  public void SetWorldPosition(double id0[])
    { SetWorldPosition_2(id0); }

  private native void SetDisplayPosition_3(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_3(id0); }

  private native void SetTranslationMode_4(int id0);
  public void SetTranslationMode(int id0)
    { SetTranslationMode_4(id0); }

  private native int GetTranslationMode_5();
  public int GetTranslationMode()
    { return GetTranslationMode_5(); }

  private native void TranslationModeOn_6();
  public void TranslationModeOn()
    { TranslationModeOn_6(); }

  private native void TranslationModeOff_7();
  public void TranslationModeOff()
    { TranslationModeOff_7(); }

  private native void SetSphereRadius_8(double id0);
  public void SetSphereRadius(double id0)
    { SetSphereRadius_8(id0); }

  private native double GetSphereRadius_9();
  public double GetSphereRadius()
    { return GetSphereRadius_9(); }

  private native void SetProperty_10(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_10(id0); }

  private native void SetSelectedProperty_11(vtkProperty id0);
  public void SetSelectedProperty(vtkProperty id0)
    { SetSelectedProperty_11(id0); }

  private native long GetProperty_12();
  public vtkProperty GetProperty() {
    long temp = GetProperty_12();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedProperty_13();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetHotSpotSize_14(double id0);
  public void SetHotSpotSize(double id0)
    { SetHotSpotSize_14(id0); }

  private native double GetHotSpotSizeMinValue_15();
  public double GetHotSpotSizeMinValue()
    { return GetHotSpotSizeMinValue_15(); }

  private native double GetHotSpotSizeMaxValue_16();
  public double GetHotSpotSizeMaxValue()
    { return GetHotSpotSizeMaxValue_16(); }

  private native double GetHotSpotSize_17();
  public double GetHotSpotSize()
    { return GetHotSpotSize_17(); }

  private native void SetHandleSize_18(double id0);
  public void SetHandleSize(double id0)
    { SetHandleSize_18(id0); }

  private native double[] GetBounds_19();
  public double[] GetBounds()
    { return GetBounds_19(); }

  private native void BuildRepresentation_20();
  public void BuildRepresentation()
    { BuildRepresentation_20(); }

  private native void StartWidgetInteraction_21(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_21(id0); }

  private native void WidgetInteraction_22(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_22(id0); }

  private native int ComputeInteractionState_23(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_23(id0,id1,id2); }

  private native void PlaceWidget_24(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_24(id0); }

  private native void ShallowCopy_25(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_25(id0); }

  private native void DeepCopy_26(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_26(id0); }

  private native void GetActors_27(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_27(id0); }

  private native void ReleaseGraphicsResources_28(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_28(id0); }

  private native int RenderOpaqueGeometry_29(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_29(id0); }

  private native int RenderTranslucentPolygonalGeometry_30(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_30(id0); }

  private native int HasTranslucentPolygonalGeometry_31();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_31(); }

  private native void Highlight_32(int id0);
  public void Highlight(int id0)
    { Highlight_32(id0); }

  public vtkSphereHandleRepresentation() { super(); }

  public vtkSphereHandleRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkSphereHandleRepresentation.java <==
// java wrapper for vtkSphereHandleRepresentation object
//

package vtk;
import vtk.*;

public class vtkSphereHandleRepresentation extends vtkHandleRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWorldPosition_2(double id0[]);
  public void SetWorldPosition(double id0[])
    { SetWorldPosition_2(id0); }

  private native void SetDisplayPosition_3(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_3(id0); }

  private native void SetTranslationMode_4(int id0);
  public void SetTranslationMode(int id0)
    { SetTranslationMode_4(id0); }

  private native int GetTranslationMode_5();
  public int GetTranslationMode()
    { return GetTranslationMode_5(); }

  private native void TranslationModeOn_6();
  public void TranslationModeOn()
    { TranslationModeOn_6(); }

  private native void TranslationModeOff_7();
  public void TranslationModeOff()
    { TranslationModeOff_7(); }

  private native void SetSphereRadius_8(double id0);
  public void SetSphereRadius(double id0)
    { SetSphereRadius_8(id0); }

  private native double GetSphereRadius_9();
  public double GetSphereRadius()
    { return GetSphereRadius_9(); }

  private native void SetProperty_10(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_10(id0); }

  private native void SetSelectedProperty_11(vtkProperty id0);
  public void SetSelectedProperty(vtkProperty id0)
    { SetSelectedProperty_11(id0); }

  private native long GetProperty_12();
  public vtkProperty GetProperty() {
    long temp = GetProperty_12();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_13();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetHotSpotSize_14(double id0);
  public void SetHotSpotSize(double id0)
    { SetHotSpotSize_14(id0); }

  private native double GetHotSpotSizeMinValue_15();
  public double GetHotSpotSizeMinValue()
    { return GetHotSpotSizeMinValue_15(); }

  private native double GetHotSpotSizeMaxValue_16();
  public double GetHotSpotSizeMaxValue()
    { return GetHotSpotSizeMaxValue_16(); }

  private native double GetHotSpotSize_17();
  public double GetHotSpotSize()
    { return GetHotSpotSize_17(); }

  private native void SetHandleSize_18(double id0);
  public void SetHandleSize(double id0)
    { SetHandleSize_18(id0); }

  private native double[] GetBounds_19();
  public double[] GetBounds()
    { return GetBounds_19(); }

  private native void BuildRepresentation_20();
  public void BuildRepresentation()
    { BuildRepresentation_20(); }

  private native void StartWidgetInteraction_21(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_21(id0); }

  private native void WidgetInteraction_22(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_22(id0); }

  private native int ComputeInteractionState_23(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_23(id0,id1,id2); }

  private native void PlaceWidget_24(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_24(id0); }

  private native void ShallowCopy_25(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_25(id0); }

  private native void DeepCopy_26(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_26(id0); }

  private native void GetActors_27(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_27(id0); }

  private native void ReleaseGraphicsResources_28(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_28(id0); }

  private native int RenderOpaqueGeometry_29(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_29(id0); }

  private native int RenderTranslucentPolygonalGeometry_30(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_30(id0); }

  private native int HasTranslucentPolygonalGeometry_31();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_31(); }

  private native void Highlight_32(int id0);
  public void Highlight(int id0)
    { Highlight_32(id0); }

  public vtkSphereHandleRepresentation() { super(); }

  public vtkSphereHandleRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
